==> kubernetes-model-1.0.31-sources.jar: io/fabric8/openshift/api/model/TagEventBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class TagEventBuilder extends TagEventFluentImpl<TagEventBuilder> implements VisitableBuilder<TagEvent,TagEventBuilder>{

     TagEventFluent<?> fluent;
public TagEventBuilder(){
    this(new TagEvent());
}
public TagEventBuilder( TagEventFluent<?> fluent ){
    this(fluent, new TagEvent());
}
public TagEventBuilder( TagEventFluent<?> fluent , TagEvent instance ){
    this.fluent = fluent; fluent.withCreated(instance.getCreated()); fluent.withDockerImageReference(instance.getDockerImageReference()); fluent.withImage(instance.getImage()); 
}
public TagEventBuilder( TagEvent instance ){
    this.fluent = this; this.withCreated(instance.getCreated()); this.withDockerImageReference(instance.getDockerImageReference()); this.withImage(instance.getImage()); 
}

public EditableTagEvent build(){
    EditableTagEvent buildable = new EditableTagEvent(fluent.getCreated(),fluent.getDockerImageReference(),fluent.getImage());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
TagEventBuilder that = (TagEventBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.51-sources.jar: io/fabric8/openshift/api/model/TagEventBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class TagEventBuilder extends TagEventFluentImpl<TagEventBuilder> implements VisitableBuilder<TagEvent,TagEventBuilder>{

     TagEventFluent<?> fluent;
public TagEventBuilder(){
    this(new TagEvent());
}
public TagEventBuilder( TagEventFluent<?> fluent ){
    this(fluent, new TagEvent());
}
public TagEventBuilder( TagEventFluent<?> fluent , TagEvent instance ){
    this.fluent = fluent; fluent.withCreated(instance.getCreated()); fluent.withDockerImageReference(instance.getDockerImageReference()); fluent.withGeneration(instance.getGeneration()); fluent.withImage(instance.getImage()); 
}
public TagEventBuilder( TagEvent instance ){
    this.fluent = this; this.withCreated(instance.getCreated()); this.withDockerImageReference(instance.getDockerImageReference()); this.withGeneration(instance.getGeneration()); this.withImage(instance.getImage()); 
}

public TagEvent build(){
    TagEvent buildable = new TagEvent(fluent.getCreated(),fluent.getDockerImageReference(),fluent.getGeneration(),fluent.getImage());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
TagEventBuilder that = (TagEventBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
